@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/commands/CmdCD.c,v 1.16 2008/05/27 01:02:34 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/commands/CmdCD.c,v 1.17 2008/12/02 22:24:53 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -877,16 +877,17 @@ badusage:
 #define CIF_LAMBDA	 7
 #define CIF_LIMIT	 8
 #define OSTYLE		 9
-#define PREFIX		10
-#define READ		11
-#define RESCALE		12
-#define SEE		13
-#define STATS		14
-#define WARNING		15
-#define CIF_WRITE	16
-#define CIF_WRITE_FLAT	17
+#define CIF_PAINT	10
+#define PREFIX		11
+#define READ		12
+#define RESCALE		13
+#define SEE		14
+#define STATS		15
+#define WARNING		16
+#define CIF_WRITE	17
+#define CIF_WRITE_FLAT	18
 #ifdef NONMANHATTAN
-#define POLYGONS	18
+#define POLYGONS	19
 #endif
 
 #define CIF_WARN_HELP  CIF_WARN_END	/* undefined by CIF module */
@@ -898,8 +899,10 @@ CmdCif(w, cmd)
 {
     int option, yesno;
     char **msg, *namep;
-    CellDef *rootDef;
+    CellDef *rootDef, *paintDef;
     Rect box;
+    TileType layer;
+    TileTypeBitMask mask;
     FILE *f;
     bool wizardHelp;
     bool flatCif = FALSE;
@@ -925,6 +928,8 @@ CmdCif(w, cmd)
 	"lambda in|out	show microns per lambda for the current style",
 	"limit [value]	limit internal grid subdivision by scalefactor value",
 	"ostyle [style]	change style for writing CIF to style",
+	"paint ciflayer magiclayer [cellname]\n"
+	"			generate CIF and paint into cell",
 	"prefix [path]	prepend path to cell names in CIF output",
 	"read file		read CIF from \"file\" into edit cell",
 	"rescale [yes|no]	allow/disallow rescaling of internal grid",
@@ -1250,6 +1255,38 @@ CmdCif(w, cmd)
 	    }
 	    CIFSeeLayer(rootDef, &box, argv[2]);
 	    return;
+
+	case CIF_PAINT:
+	    if ((argc != 4) && (argc != 5)) goto wrongNumArgs;
+	    if (!ToolGetBox(&rootDef, &box))
+	    {
+		TxError("Use the box to select the area in");
+		TxError(" which you want to see CIF.\n");
+		return;
+	    }
+	    if (argc == 5)
+	    {
+		paintDef = DBCellLookDef(argv[4]);
+		if (paintDef == (CellDef *)NULL)
+		{
+		    paintDef = DBCellNewDef(argv[4], (char *)NULL);
+		    DBCellSetAvail(paintDef);
+		}
+	    }
+	    else
+		paintDef = rootDef;
+
+	    layer = DBTechNoisyNameType(argv[3]);
+	    if (layer >= TT_TECHDEPBASE)
+	    {
+		CIFPaintLayer(rootDef, &box, argv[2], layer, paintDef);
+
+		/* Refresh the layout drawing */
+		TTMaskSetOnlyType(&mask, layer);
+		DBWAreaChanged(paintDef, &box, DBW_ALLWINDOWS, &mask);
+		DRCCheckThis(paintDef, TT_CHECKPAINT, &box);
+	    }
+	    return;
 	
 	case STATS:
 	    CIFPrintStats();
