@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/database/DBcellname.c,v 1.6 2008/01/04 20:34:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/database/DBcellname.c,v 1.7 2008/02/21 17:52:19 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -1059,7 +1059,7 @@ dbLockUseFunc(selUse, use, transform, data)
 {
     bool dolock = *((bool *)data);
 
-    if (!DBIsChild(use, EditCellUse))
+    if (EditCellUse && !DBIsChild(use, EditCellUse))
     {
 	TxError("Cell %s (%s) isn't a child of the edit cell.\n",
 		use->cu_id, use->cu_def->cd_name);
@@ -1124,8 +1124,11 @@ DBLockUse(UseName, bval)
 
     if (UseName == NULL)
     {
-	SelEnumCells(TRUE, (int *)NULL, (SearchContext *)NULL,
-		dbLockUseFunc, (ClientData)&bval);
+	if (EditCellUse == NULL)
+	    TxError("Cannot set lock in a non-edit cell!\n");
+	else
+	    SelEnumCells(TRUE, (int *)NULL, (SearchContext *)NULL,
+			dbLockUseFunc, (ClientData)&bval);
     }
     else
     {
