@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/database/DBtpaint2.c,v 1.6 2008/02/10 19:06:31 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/database/DBtpaint2.c,v 1.7 2008/11/25 13:40:06 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -672,7 +672,8 @@ dbComposeEraseContact(lpImage, lpErase)
     {
 	for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
 	    if (PlaneMaskHasPlane(lpImage->l_pmask, pNum))
-		SETERASE(lpImage->l_type, lpErase->l_type, pNum, lpImage->l_type);
+		// SETERASE(lpImage->l_type, lpErase->l_type, pNum, lpImage->l_type);
+		SETERASE(lpImage->l_type, lpErase->l_type, pNum, TT_SPACE);
     }
     else
     {
