@@ -20,7 +20,7 @@
  */
 
 #ifndef	lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/drc/DRCcontin.c,v 1.2 2007/12/24 22:56:44 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/drc/DRCcontin.c,v 1.3 2008/02/29 00:14:05 tim Exp $";
 #endif	/* not lint */
 
 #include <stdio.h>
@@ -487,6 +487,7 @@ DRCContinuous ()
 
 #ifdef MAGIC_WRAPPER
 	    /* Execute pending Tcl events, so the DRC process doesn't block. */
+	    UndoEnable();
 	    while (Tcl_DoOneEvent(TCL_DONT_WAIT))
 	    {
 		if (DRCStatus == DRC_BREAK_PENDING)
@@ -496,6 +497,7 @@ DRCContinuous ()
 		    return;
 	        }
 	    }
+	    UndoDisable();
 	    /* fprintf(stderr, "DRC continuing internally. . .\n"); fflush(stderr); */
 #else
 #ifndef USE_IO_PROBE
