@@ -19,7 +19,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/extract/ExtArray.c,v 1.1.1.1 2006/04/10 22:03:14 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/extract/ExtArray.c,v 1.2 2007/12/24 22:56:44 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -656,11 +656,11 @@ extArrayNodeName(np, ha, et1, et2)
 
     NODETOTILE(np, et1, tp);	/* tp = extHierLookTile(np, et1); */
     if (tp && TiGetType(tp) != TT_SPACE && extHasRegion(tp, extUnInit))
-	return (extArrayTileToNode(tp, et1, ha, TRUE));
+	return (extArrayTileToNode(tp, np->nreg_pnum, et1, ha, TRUE));
 
     NODETOTILE(np, et2, tp);	/* tp = extHierLookTile(np, et2); */
     if (tp && TiGetType(tp) != TT_SPACE && extHasRegion(tp, extUnInit))
-	return (extArrayTileToNode(tp, et2, ha, TRUE));
+	return (extArrayTileToNode(tp, np->nreg_pnum, et2, ha, TRUE));
 
     return ("(none)");
 }
@@ -708,8 +708,9 @@ extArrayNodeName(np, ha, et1, et2)
  */
 
 char *
-extArrayTileToNode(tp, et, ha, doHard)
+extArrayTileToNode(tp, pNum, et, ha, doHard)
     Tile *tp;
+    int pNum;
     ExtTree *et;
     HierExtractArg *ha;
     bool doHard;	/* If TRUE, we look up this node's name the hard way
@@ -738,7 +739,7 @@ extArrayTileToNode(tp, et, ha, doHard)
     }
 
     if (!DebugIsSet(extDebugID, extDebNoHard))
-	if (reg = (LabRegion *) extArrayHardNode(tp, def, ha))
+	if (reg = (LabRegion *) extArrayHardNode(tp, pNum, def, ha))
 	    goto found;
 
     /* Blew it */
@@ -873,8 +874,9 @@ extArrayRange(dstp, lo, hi, prevRange, followRange)
  */
 
 LabRegion *
-extArrayHardNode(tp, def, ha)
+extArrayHardNode(tp, pNum, def, ha)
     Tile *tp;
+    int pNum;
     CellDef *def;
     HierExtractArg *ha;
 {
@@ -885,7 +887,7 @@ extArrayHardNode(tp, def, ha)
 
     arg.hw_ha = ha;
     arg.hw_label = (Label *) NULL;
-    arg.hw_mask = DBPlaneTypes[DBPlane(type)];
+    arg.hw_mask = DBPlaneTypes[pNum];
     TTMaskAndMask(&arg.hw_mask, &DBConnectTbl[type]);
     arg.hw_tpath.tp_last = &labelBuf[sizeof labelBuf - 3];
     arg.hw_tpath.tp_first = arg.hw_tpath.tp_next = labelBuf;
