@@ -20,7 +20,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/extract/ExtHier.c,v 1.1.1.1 2006/04/10 22:03:14 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/extract/ExtHier.c,v 1.3 2007/12/24 22:56:44 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -46,8 +46,6 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/
     /* Passed to search functions by extHierConnections */
 ExtTree *extHierCumFlat;	/* Cum buffer */
 ExtTree *extHierOneFlat;	/* Subtree being compared with extHierCumFlat */
-Tile *extHierOneTile;		/* Tile from extHierOneFlat */
-int extHierPNum;		/* Plane on which extHierOneTile lives */
 
     /* List of free cells around for use in yanking subtrees */
 ExtTree *extHierFreeOneList = (ExtTree *) NULL;
@@ -86,14 +84,16 @@ extHierConnections(ha, cumFlat, oneFlat)
     HierExtractArg *ha;
     ExtTree *cumFlat, *oneFlat;
 {
+    int pNum;
     CellDef *sourceDef = oneFlat->et_use->cu_def;
 
     extHierCumFlat = cumFlat;
     extHierOneFlat = oneFlat;
-    for (extHierPNum = PL_TECHDEPBASE; extHierPNum < DBNumPlanes; extHierPNum++)
+    for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
     {
+	ha->hierPNum = pNum;
 	(void) DBSrPaintArea((Tile *) NULL,
-		sourceDef->cd_planes[extHierPNum], &ha->ha_subArea,
+		sourceDef->cd_planes[pNum], &ha->ha_subArea,
 		&DBAllButSpaceBits, extHierConnectFunc1, (ClientData) ha);
     }
 }
@@ -119,6 +119,7 @@ extHierConnectFunc1(oneTile, ha)
     CellDef *cumDef = extHierCumFlat->et_use->cu_def;
     Rect r;
     TileTypeBitMask mask, *connected;
+    TileType rtype;
     int i;
 
     /*
@@ -126,20 +127,41 @@ extHierConnectFunc1(oneTile, ha)
      * yank buffer cumDef.  Adjust connectivity for each tile found.
      * Widen the rectangle to detect connectivity by abutment.
      */
-    extHierOneTile = oneTile;
-    connected = &(ExtCurStyle->exts_nodeConn[TiGetType(oneTile)]);
+    ha->hierOneTile = oneTile;
+    ha->hierType = TiGetTypeExact(oneTile);
+
+#ifdef NONMANHATTAN
+    if (IsSplit(oneTile))
+    {
+	rtype = ha->hierType;
+	ha->hierType = (rtype & TT_SIDE) ? SplitRightType(oneTile) :
+		SplitLeftType(oneTile);
+    }  
+#endif
+
+    connected = &(ExtCurStyle->exts_nodeConn[ha->hierType]);
     TITORECT(oneTile, &r);
     GEOCLIP(&r, &ha->ha_subArea);
     r.r_xbot--, r.r_ybot--, r.r_xtop++, r.r_ytop++;
     for (i = PL_TECHDEPBASE; i < DBNumPlanes; i++)
     {
+	ha->hierPNumBelow = i;
 	TTMaskAndMask3(&mask, connected, &DBPlaneTypes[i]);
 	if (!TTMaskIsZero(&mask))
-	    (void) DBSrPaintArea((Tile *) NULL, cumDef->cd_planes[i], &r,
-		((i == extHierPNum) ? &DBAllButSpaceBits : connected),
-		extHierConnectFunc2, (ClientData) ha);
+	{
+#ifdef NONMANHATTAN
+	    if (IsSplit(oneTile))
+		DBSrPaintNMArea((Tile *) NULL, cumDef->cd_planes[i],
+			rtype, &r,
+			((i == ha->hierPNum) ? &DBAllButSpaceBits : connected),
+			extHierConnectFunc2, (ClientData) ha);
+	    else
+#endif
+		DBSrPaintArea((Tile *) NULL, cumDef->cd_planes[i], &r,
+			((i == ha->hierPNum) ? &DBAllButSpaceBits : connected),
+			extHierConnectFunc2, (ClientData) ha);
+	}
     }
-
     return (0);
 }
 
@@ -147,8 +169,8 @@ extHierConnectFunc1(oneTile, ha)
  * extHierConnectFunc2 --
  *
  * Called once for each tile 'cum' in extHierCumFlat->et_use->cu_def
- * on the same plane as extHierOneTile that also overlaps or abuts
- * the intersection of extHierOneTile with ha->ha_subArea, and for tiles
+ * on the same plane as ha->hierOneTile that also overlaps or abuts
+ * the intersection of ha->hierOneTile with ha->ha_subArea, and for tiles
  * in other planes that may connect.
  *
  * Results:
@@ -156,7 +178,7 @@ extHierConnectFunc1(oneTile, ha)
  *
  * Side effects:
  *	Makes a connection between the nodes of the two tiles
- *	if the types of extHierOneTile and 'cum' connect.
+ *	if the types of ha->hierOneTile and 'cum' connect.
  *	Otherwise, if the tiles actually overlap (as opposed
  *	to merely abut), mark it with feedback as an error.
  */
@@ -168,16 +190,17 @@ extHierConnectFunc2(cum, ha)
 {
     HashTable *table = &ha->ha_connHash;
     Node *node1, *node2;
+    TileType ttype;
     HashEntry *he;
     NodeName *nn;
     char *name;
     Rect r;
 
     /* Compute the overlap area */
-    r.r_xbot = MAX(LEFT(extHierOneTile), LEFT(cum));
-    r.r_xtop = MIN(RIGHT(extHierOneTile), RIGHT(cum));
-    r.r_ybot = MAX(BOTTOM(extHierOneTile), BOTTOM(cum));
-    r.r_ytop = MIN(TOP(extHierOneTile), TOP(cum));
+    r.r_xbot = MAX(LEFT(ha->hierOneTile), LEFT(cum));
+    r.r_xtop = MIN(RIGHT(ha->hierOneTile), RIGHT(cum));
+    r.r_ybot = MAX(BOTTOM(ha->hierOneTile), BOTTOM(cum));
+    r.r_ytop = MIN(TOP(ha->hierOneTile), TOP(cum));
 
     /* If the tiles don't even touch, they don't connect */
     if (r.r_xtop < r.r_xbot || r.r_ytop < r.r_ybot
@@ -185,19 +208,27 @@ extHierConnectFunc2(cum, ha)
 	return (0);
 
     /*
-     * Only make a connection if the types of 'extHierOneTile' and 'cum'
+     * Only make a connection if the types of 'ha->hierOneTile' and 'cum'
      * connect.  If they overlap and don't connect, it is an error.
      * If they do connect, mark their nodes as connected.
      */
-    if (extConnectsTo(TiGetType(extHierOneTile), TiGetType(cum),
-		ExtCurStyle->exts_nodeConn))
+
+    ttype = TiGetTypeExact(cum);
+
+#ifdef NONMANHATTAN
+    if (IsSplit(cum))
+	ttype = (ttype & TT_SIDE) ? SplitRightType(cum) : SplitLeftType(cum);
+#endif
+
+    if (extConnectsTo(ha->hierType, ttype, ExtCurStyle->exts_nodeConn))
     {
-	name = (*ha->ha_nodename)(cum, extHierCumFlat, ha, TRUE);
+	name = (*ha->ha_nodename)(cum, ha->hierPNumBelow, extHierCumFlat, ha, TRUE);
 	he = HashFind(table, name);
 	nn = (NodeName *) HashGetValue(he);
 	node1 = nn ? nn->nn_node : extHierNewNode(he);
 
-	name = (*ha->ha_nodename)(extHierOneTile, extHierOneFlat, ha, TRUE);
+	name = (*ha->ha_nodename)(ha->hierOneTile, ha->hierPNum, extHierOneFlat,
+		ha, TRUE);
 	he = HashFind(table, name);
 	nn = (NodeName *) HashGetValue(he);
 	node2 = nn ? nn->nn_node : extHierNewNode(he);
@@ -320,7 +351,7 @@ extHierAdjustments(ha, cumFlat, oneFlat, lookFlat)
     for (np = oneFlat->et_nodes; np; np = np->nreg_next)
     {
 	NODETOTILE(np, lookFlat, tp);  /* tp = extHierLookTile(np, lookFlat); */
-	if (tp	&& (name = (*ha->ha_nodename)(tp, lookFlat, ha, FALSE))
+	if (tp	&& (name = (*ha->ha_nodename)(tp, np->nreg_pnum, lookFlat, ha, FALSE))
 		&& (he = HashLookOnly(&ha->ha_connHash, name))
 		&& (nn = (NodeName *) HashGetValue(he)))
 	{
