@@ -23,7 +23,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/extract/ExtLength.c,v 1.2 2007/04/20 17:57:00 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/extract/ExtLength.c,v 1.3 2008/01/29 02:41:57 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -505,7 +505,7 @@ extLengthLabelsFunc(scx, label, tpath)
 	- sizeof newLab->lab_text + 1;
     newLab = (Label *) mallocMagic((unsigned) len);
     newLab->lab_type = label->lab_type;
-    GeoTransPos(&scx->scx_trans, label->lab_pos, newLab->lab_pos);
+    GeoTransPos(&scx->scx_trans, label->lab_just, newLab->lab_just);
     GeoTransRect(&scx->scx_trans, &label->lab_rect, &newLab->lab_rect);
     newLab->lab_next = extLengthLabelList;
     extLengthLabelList = newLab;
@@ -583,7 +583,7 @@ extPathLabelFunc(rect, text, childLab, pLabList)
     lab = (Label *) mallocMagic((unsigned) len);
     lab->lab_type = childLab->lab_type;
     lab->lab_rect = *rect;
-    lab->lab_pos = GEO_CENTER;	/* Irrelevant */
+    lab->lab_just = GEO_CENTER;	/* Irrelevant */
     lab->lab_next = *pLabList;
 
     /* Cons to front of list */
