@@ -80,7 +80,7 @@ groglDrawGrid (prect, outline, clip)
     ysize = prect->r_ytop - prect->r_ybot;
     if (!xsize || !ysize)
 	return FALSE;
-    if (GRID_TOO_SMALL(xsize, ysize, GR_NUM_GRIDS))
+    if (GRID_TOO_SMALL(xsize, ysize))
 	return FALSE;
     
     xstart = prect->r_xbot % xsize;
