@@ -9,14 +9,14 @@
 # revision C: Adds a layer manager toolbar on the left side
 # revision D: Adds a menubar on top with cell and tech manager tools
 
-global MagicBLT
+global treeViews
 global windowsopen
 global Glyph
 global Opts
 global Winopts
 
-set MagicBLT 0
-if {! [catch {package require BLT}]} {set MagicBLT 1}
+set treeViews 0
+if {![catch {package require BLT}]} {set treeViews 1}
 
 # Simple console commands (like TkCon, but much simpler)
 
@@ -232,17 +232,17 @@ menu .winmenu -tearoff 0
 # The cell manager
 
 proc magic::makecellmanager { mgrpath } {
-   global MagicBLT
+   global treeViews
 
-   if {$MagicBLT} {
+   if {$treeViews} {
       toplevel ${mgrpath}
       wm withdraw ${mgrpath}
       frame ${mgrpath}.actionbar
       frame ${mgrpath}.box
       frame ${mgrpath}.target
-      blt::hiertable ${mgrpath}.box.view -bg white -allowduplicates false -hideroot true \
-	   -yscrollcommand "${mgrpath}.box.vert set" \
-	   -xscrollcommand "${mgrpath}.box.vert set"
+      blt::hiertable ${mgrpath}.box.view -bg white -allowduplicates false \
+		-hideroot true -yscrollcommand "${mgrpath}.box.vert set" \
+		-xscrollcommand "${mgrpath}.box.vert set"
       scrollbar ${mgrpath}.box.vert -orient vertical -command "${mgrpath}.box.view yview"
 
       pack ${mgrpath}.actionbar -side top -fill x
@@ -287,8 +287,8 @@ proc magic::addlistinstance {instin} {
 }
 
 proc magic::cellmanager {{option "update"}} {
-   global MagicBLT
-   if {$MagicBLT} {
+   global treeViews
+   if {$treeViews} {
 
       # Check for existence of the manager widget
       if {[catch {wm state .cellmgr}]} {
@@ -568,7 +568,7 @@ magic::tag see "magic::toolupdate %W %1 %2"
 magic::tag tech "magic::techrebuild %W %1; magic::captions %1"
 magic::tag drc "magic::drcupdate %1"
 magic::tag path "magic::techmanager update"
-if {$MagicBLT} {
+if {$treeViews} {
    magic::tag cellname "magic::mgrupdate %W %1"
    magic::tag select "magic::mgrselect %R"
    magic::tag cif "magic::mgrupdate %W %1"
@@ -734,7 +734,7 @@ proc magic::toolupdate {win {yesno "yes"} {layerlist "none"}} {
 
 # Redirect and reformat Tcl output of "select" command
 
-if {$MagicBLT} {
+if {$treeViews} {
    proc magic::mgrselect {{sstr ""}} {
       # Make sure we have a valid option, and the cell manager exists.
       if {$sstr == ""} {
@@ -777,20 +777,22 @@ if {$MagicBLT} {
       }
       magic::tag select $savetag
    }
+}
 
-   # Update cell and tech managers in response to a cif or gds read command
+# Update cell and tech managers in response to a cif or gds read command
 
-   proc magic::mgrupdate {win {cmdstr ""}} {
-      if {${cmdstr} == "read"} {
-	 magic::cellmanager
-	 magic::captions
-	 magic::techmanager update
-      } elseif {${cmdstr} == "delete" || ${cmdstr} == "rename"} {
-	 magic::cellmanager
-	 magic::captions
-      } elseif {${cmdstr} == "writeable"} {
-	 magic::captions
-      }
+proc magic::mgrupdate {win {cmdstr ""}} {
+   global treeViews
+
+   if {${cmdstr} == "read"} {
+      if {$treeViews} { magic::cellmanager }
+      magic::captions
+      magic::techmanager update
+   } elseif {${cmdstr} == "delete" || ${cmdstr} == "rename"} {
+      if {$treeViews} { magic::cellmanager }
+      magic::captions
+   } elseif {${cmdstr} == "writeable"} {
+      magic::captions
    }
 }
 
@@ -1067,7 +1069,7 @@ proc magic::makescrollbar { fname orient win } {
 
 proc magic::openwrapper {{cell ""} {framename ""}} {
    global windowsopen
-   global MagicBLT
+   global treeViews
    global Glyph
    global Opts
    global Winopts
@@ -1203,7 +1205,7 @@ proc magic::openwrapper {{cell ""} {framename ""}} {
 		grid forget ${framename}.toolbar } }]
 
    .winmenu add radio -label ${framename} -variable Opts(target) -value ${winname}
-   if {$MagicBLT} {
+   if {$treeViews} {
       $m add check -label "Cell Manager" -variable Opts(cellmgr) \
 		-command [subst { magic::cellmanager create; \
 		if { \$Opts(cellmgr) } { \
@@ -1293,14 +1295,14 @@ proc magic::openwrapper {{cell ""} {framename ""}} {
 # Delete the wrapper and the layout window in it.
 
 proc magic::closewrapper { framename } {
-   global MagicBLT
+   global treeViews
    global Opts
 
    # Remove this window from the target list in cellmanager
 
    if { $Opts(target) == "${framename}.magic" } {
       set Opts(target) "default"
-      if {$MagicBLT} {
+      if {$treeViews} {
          if {![catch {wm state .cellmgr}]} {
 	    .cellmgr.target.list configure -text "default"
 	 }
