@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) ="$Header: /usr/cvsroot/magic-7.5/textio/txCommands.c,v 1.2 2006/05/13 07:36:14 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) ="$Header: /usr/cvsroot/magic-7.5/textio/txCommands.c,v 1.3 2007/12/24 22:56:45 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -1135,6 +1135,7 @@ TxTclDispatch(clientData, argc, argv)
     bool result;
     int n, asize;
     TxCommand *tclcmd;
+    unsigned char lastdrc;
 
     if (argc > TX_MAXARGS)
     {
@@ -1142,8 +1143,6 @@ TxTclDispatch(clientData, argc, argv)
 	return;
     }
 
-    DRCBreak();
-
     SigIOReady = FALSE;
     SigInterruptOnSigIO = TRUE;
     SigInterruptPending = FALSE;
@@ -1170,6 +1169,12 @@ TxTclDispatch(clientData, argc, argv)
     else
 	tclcmd->tx_wid = WIND_UNKNOWN_WINDOW;
 
+    /* Prevent DRCContinuous from running in the middle of a command	*/
+    /* (Note that Tcl_CancelIdleCall() does *not* work. . .)		*/
+
+    lastdrc = DRCStatus;
+    DRCStatus = DRC_IN_PROGRESS;
+
     result = WindSendCommand((MagWindow *)clientData, tclcmd);
     TxFreeCommand(tclcmd);
     TxCommandNumber++;
@@ -1178,14 +1183,25 @@ TxTclDispatch(clientData, argc, argv)
 	TxPrintf("[Interrupted]\n");
 
     if (result != FALSE)
-    {
 	WindUpdate();
-	Tcl_DoWhenIdle(DRCContinuous, NULL);
-    }
 
     SigInterruptPending = FALSE;
     SigInterruptOnSigIO = FALSE;
     SigIOReady = FALSE;
+
+    /* Force a break of DRCContinuous() so we don't run DRC on an	*/
+    /* invalid database.						*/
+
+    /* Avoid breaking on "*bypass" commands.  Technically, one could	*/
+    /* set up a command to *bypass that alters the database and crashes	*/
+    /* magic.  This is a total hack.  We should flag an invalid		*/
+    /* database instead.						*/
+
+    DRCStatus = lastdrc;
+    if (strcmp(argv[0], "*bypass") && strcmp(argv[0], "windownames")) DRCBreak();
+
+    /* Reinstate the idle call */
+    if (result != FALSE) Tcl_DoWhenIdle(DRCContinuous, NULL);
 }
 #else  /* !MAGIC_WRAPPER */
 
